@@ -155,7 +155,14 @@ void segatex::segatex_write_to_my_policy()
 	ifstream os_pre;
 	os_pre.open(my_policy_file);
 	if(os_pre){
+                QFile file( my_policy_file );
+                if ( file.open( IO_ReadWrite ) ) {
+                        QTextStream stream( &file );
+                        stream << textEdit2->text();
+                        textEdit2->setModified( FALSE );
+                }
 		os_pre.close();
+
 		ofstream os;
 		os.open(load_my_policy_file);
 		if(os){
@@ -203,7 +210,7 @@ void segatex::segatex_write_to_my_policy()
 }
 void segatex::segatex_show_yum_update()
 {
-        status_label_1->setText("yum install/updating SELinx related rpms. Please wait for a while...");
+        status_label_1->setText("yum install/updating SELinx related rpms and audit rpm. Please wait for a while...");
 }
 
 void segatex::segatex_yum_update()
@@ -220,7 +227,7 @@ void segatex::segatex_yum_update()
 		char buffer[SIZE_TMP];
 		int chars_read;
 		memset(buffer, '\0', sizeof(buffer));
-		read_fp_install = popen("yum -y install selinux-policy* libsepol policycoreutils checkpolicy", "r");
+		read_fp_install = popen("yum -y install audit selinux-policy* libsepol policycoreutils checkpolicy", "r");
 		if(read_fp_install != NULL){
 			chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp_install);
 			while(chars_read>0){
@@ -231,7 +238,7 @@ void segatex::segatex_yum_update()
 			}
 			pclose(read_fp_install);
 		}
-		read_fp = popen("yum -y update selinux-policy* libsepol policycoreutils checkpolicy", "r");
+		read_fp = popen("yum -y update audit selinux-policy* libsepol policycoreutils checkpolicy", "r");
 		if(read_fp != NULL){
 			chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
 			while(chars_read>0){
@@ -1199,7 +1206,7 @@ void segatex::segatex_show_interface()
 					p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 					os_policy << "####################################################" << endl;
-					os_policy << "##### This file was generated by segatex2.09" << endl;
+					os_policy << "##### This file was generated by segatex2.10" << endl;
 					os_policy << "####################################################" << endl;
 					os_policy << "module my_policy_by_segatex 1.0.0;" << endl << endl;
 					os_policy << "require {" << endl;
